@@ -1,5 +1,5 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
 Date: 2021/1/6 12:08
 Desc: 金十数据-数据中心-主要机构-宏观经济
@@ -78,7 +78,7 @@ def macro_cons_gold_volume() -> pd.Series:
     big_df = temp_df
     big_df.columns = ['总库存']
 
-    for i in tqdm(range(for_times)):
+    for i in tqdm(range(for_times), leave=False):
         params = {
             "max_date": temp_df.index[-1],
             "category": "etf",
@@ -160,7 +160,7 @@ def macro_cons_gold_change():
     big_df = temp_df
     big_df.columns = ['增持/减持']
 
-    for i in tqdm(range(for_times)):
+    for i in tqdm(range(for_times), leave=False):
         params = {
             "max_date": temp_df.index[-1],
             "category": "etf",
@@ -243,7 +243,7 @@ def macro_cons_gold_amount():
     big_df = temp_df
     big_df.columns = ['总价值']
 
-    for i in tqdm(range(for_times)):
+    for i in tqdm(range(for_times), leave=False):
         params = {
             "max_date": temp_df.index[-1],
             "category": "etf",
@@ -642,58 +642,6 @@ def macro_cons_opec_month():
     20200312:fix:由于 “厄瓜多尔” 已经有几个月没有更新数据，在这里加以剔除
     https://datacenter.jin10.com/reportType/dc_opec_report
     :return: pandas.Series
-                阿尔及利亚    安哥拉  厄瓜多尔    加蓬     伊朗    伊拉克    科威特    利比亚   尼日利亚  \
-    2017-01-18  108.0  172.4  54.5  21.3  372.0  463.2  281.2   60.8  154.2
-    2017-02-13  104.5  165.1  52.7  19.9  377.5  447.6  271.8   67.5  157.6
-    2017-03-14  105.3  164.1  52.6  19.4  381.4  441.4  270.9   66.9  160.8
-    2017-04-12  105.6  161.4  52.6  19.8  379.0  440.2  270.2   62.2  154.5
-    2017-05-11  104.7  169.2  52.4  20.6  375.9  437.3  270.2   55.0  150.8
-    2017-06-13  105.9  161.3  52.8  20.4  379.5  442.4  270.5   73.0  168.0
-    2017-07-12  106.0  166.8  52.7  19.7  379.0  450.2  270.9   85.2  173.3
-    2017-08-10  105.9  164.6  53.6  20.5  382.4  446.8  270.3  100.1  174.8
-    2017-09-12  106.5  164.6  53.7  17.3  382.8  444.8  270.2   89.0  186.1
-    2017-10-11  104.6  164.1  53.6  20.1  382.7  449.4  270.0   92.3  185.5
-    2017-11-13  101.2  171.1  54.1  20.3  382.3  438.3  270.8   96.2  173.8
-    2017-12-13  101.3  158.1  53.3  19.7  381.8  439.6  270.3   97.3  179.0
-    2018-01-18  103.7  163.3  52.6  19.7  382.9  440.5  270.0   96.2  186.1
-    2018-04-12   98.4  152.4  51.8  18.3  381.4  442.6  270.4   96.8  181.0
-    2018-05-14   99.7  151.5  52.0  18.3  382.3  442.9  270.5   98.2  179.1
-    2018-06-12  103.1  152.5  51.9  18.9  382.9  445.5  270.1   95.5  171.1
-    2018-07-11  103.9  143.1  51.9  19.0  379.9  453.3  273.1   70.8  166.0
-    2018-08-13  106.2  145.6  52.5  18.8  373.7  455.6  279.1   66.4  166.7
-    2018-09-12  104.5  144.8  52.9  18.7  358.4  464.9  280.2   92.6  172.5
-    2018-10-11  104.9  151.9  53.1  18.7  344.7  465.0  281.2  105.3  174.8
-    2018-11-13  105.4  153.3  52.5  18.6  329.6  465.4  276.4  111.4  175.1
-    2018-12-12  105.2  152.1  52.5  17.6  295.4  463.1  280.9  110.4  173.6
-    2019-03-14  102.6  145.7  52.2  20.3  274.3  463.3  270.9   90.6  174.1
-    2019-04-10  101.8  145.4  52.4  21.4  269.8  452.2  270.9  109.8  173.3
-    2019-06-13  102.9  147.1  52.9  21.1  237.0  472.4  271.0  117.4  173.3
-                    沙特    阿联酋   委内瑞拉   欧佩克产量
-    2017-01-18  1047.4  307.1  202.1  3308.5
-    2017-02-13   994.6  293.1  200.4  3213.9
-    2017-03-14   979.7  292.5  198.7  3195.8
-    2017-04-12   999.4  289.5  197.2  3192.8
-    2017-05-11   995.4  284.2  195.6  3173.2
-    2017-06-13   994.0  288.5  196.3  3213.9
-    2017-07-12   995.0  289.8  193.8  3261.1
-    2017-08-10  1006.7  290.5  193.2  3286.9
-    2017-09-12  1002.2  290.1  191.8  3275.5
-    2017-10-11   997.5  290.5  189.0  3274.8
-    2017-11-13  1000.0  291.1  186.3  3258.9
-    2017-12-13   999.6  288.3  183.4  3244.8
-    2018-01-18   991.8  287.8  174.5  3241.6
-    2018-04-12   993.4  286.4  148.8  3195.8
-    2018-05-14   995.9  287.2  143.6  3193.0
-    2018-06-12   998.7  286.5  139.2  3186.9
-    2018-07-11  1042.0  289.7  134.0  3232.7
-    2018-08-13  1038.7  295.9  127.8  3232.3
-    2018-09-12  1040.1  297.2  123.5  3256.5
-    2018-10-11  1051.2  300.4  119.7  3276.1
-    2018-11-13  1063.0  316.0  117.1  3290.0
-    2018-12-12  1101.6  324.6  113.7  3296.5
-    2019-03-14  1008.7  307.2  100.8  3054.9
-    2019-04-10   979.4  305.9   73.2  3002.2
-    2019-06-13   969.0  306.1   74.1  2987.6
     """
     t = time.time()
     big_df = pd.DataFrame()
@@ -732,6 +680,7 @@ def macro_cons_opec_month():
         except:
             temp_df = temp_df[['阿尔及利亚', '安哥拉', '加蓬', '伊朗', '伊拉克', '科威特', '利比亚', '尼日利亚', '沙特',
                                '阿联酋', '委内瑞拉', '欧佩克产量']].iloc[-1, :]
+        temp_df.dropna(inplace=True)
         big_df[temp_df.name] = temp_df
     big_df = big_df.T
     big_df.columns.name = "日期"
@@ -742,18 +691,25 @@ def macro_cons_opec_month():
 if __name__ == "__main__":
     macro_cons_gold_volume_df = macro_cons_gold_volume()
     print(macro_cons_gold_volume_df)
+
     macro_cons_gold_change_df = macro_cons_gold_change()
     print(macro_cons_gold_change_df)
+
     macro_cons_gold_amount_df = macro_cons_gold_amount()
     print(macro_cons_gold_amount_df)
+
     print(pd.concat([macro_cons_gold_volume_df, macro_cons_gold_change_df, macro_cons_gold_amount_df], axis=1))
 
     macro_cons_silver_volume_df = macro_cons_silver_volume()
     print(macro_cons_silver_volume_df)
+
     macro_cons_silver_change_df = macro_cons_silver_change()
     print(macro_cons_silver_change_df)
+
     macro_cons_silver_amount_df = macro_cons_silver_amount()
     print(macro_cons_silver_amount_df)
+
     print(pd.concat([macro_cons_silver_volume_df, macro_cons_silver_change_df, macro_cons_silver_amount_df], axis=1))
+
     macro_cons_opec_month_df = macro_cons_opec_month()
     print(macro_cons_opec_month_df)
